summaryrefslogtreecommitdiff
path: root/internal/config/config.go
diff options
context:
space:
mode:
authorPaul Buetow <pbuetow@mimecast.com>2020-07-03 14:13:13 +0100
committerPaul Buetow <pbuetow@mimecast.com>2020-08-13 11:37:24 +0100
commitc5a0ba7d29da7effa0ae18bffa10fc0be359b8e7 (patch)
treede4874740a5ddeb6eb29c887f6e121c61a1f8f3c /internal/config/config.go
parent8f9f9766cecec4a42ffb4d14ba9b7efc2ed204ad (diff)
bump up version to 3.0.0. can run continuous background mapreduce queries, useful for log file monitorig for example. breaking protocol change which allows to mapreduce aggreate messages containing the default field separator |. add of more unit tests. add logformat mapreduce query keyword. add set mapreduce clause support and support to evaluate built-in functions such as md5sum() and maskdigits().v3.0.0
Diffstat (limited to 'internal/config/config.go')
-rw-r--r--internal/config/config.go9
1 files changed, 6 insertions, 3 deletions
diff --git a/internal/config/config.go b/internal/config/config.go
index 39149bc..dc96d6b 100644
--- a/internal/config/config.go
+++ b/internal/config/config.go
@@ -7,10 +7,13 @@ import (
)
// ControlUser is used for various DTail specific operations.
-const ControlUser string = "DTAIL-CONTROL-USER"
+const ControlUser string = "DTAIL-CONTROL"
-// BackgroundUser is used for non-interactive scheduled queries and log monitoring and such.
-const BackgroundUser string = "DTAIL-BACKGROUND-USER"
+// ScheduleUser is used for non-interactive scheduled mapreduce queries.
+const ScheduleUser string = "DTAIL-SCHEDULE"
+
+// ContinuousUser is used for non-interactive continuous mapreduce queries.
+const ContinuousUser string = "DTAIL-CONTINUOUS"
// Client holds a DTail client configuration.
var Client *ClientConfig